package wls.tools.logreport;

import java.io.BufferedInputStream;
import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.DataInputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.io.InputStream;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;
import java.util.GregorianCalendar;
import java.util.Hashtable;
import java.util.Locale;
import java.util.Properties;
import java.util.StringTokenizer;
import java.util.Vector;

public class Parameter {

	private static Parameter instance = null;	
	
	public static final String PARAM = "WlsLogReport version={Weblogic version : 6/7/8/9/10/etc ...} input={file/liste/directory} [output={directory}{Default=document_root}]] [after={yyyy/MM/dd hh'h'mm}] [before={yyyy/MM/dd hh'h'mm}] [day={yyyy/MM/dd}] [exclude_ranger_houre={[hh:mm-hh:mm]}] [occurance_log=[true/false}{Default=true}] [percent_approximate={[0-100]}{Default=50}] [exact_match={true/false}{Default=false}] [debug={true/false}{Default=false}] DateFormat =\"MMM dd, yyyy hh:mm:ss aaa z\" DateLanguage=\"en\" DateCountry=\"US\" [ExcludeIdFile=\"{file}.id\"] [StackDepth=\"{nb of stack line to compare}\"]" + "\n";
	
	public static BufferedWriter errorLog = null;		// unparsable log
	public static BufferedWriter unknownIDLog = null;	// unknown BEA ID log
	public static BufferedWriter excludeIDLog = null;	// exclude BEA ID log

	public static String rootOutput = null;			// output folder
	public static boolean occuranceLog = false;
	public static float percentApproximate = 0;		// % approximat for error message to be compared
	public static boolean debug = false;			// debug mode
	public static boolean exactMatch = false;		// tunr off the % approximat
	public static String error_message = null;
	public static String version = null;			// WLS version 6/7/8/9/10
	
	public static String dateFilter = "yyyy/MM/dd hh'h'mm";
	public static String language = "fr";
	public static String country = "Fr";
	public static Locale locale = null;
	public static SimpleDateFormat dateFormat = null;	

	public static Date afterDate = null;
	public static Date beforeDate = null;
	
	public static GregorianCalendar 	start_houre = null; 
	public static GregorianCalendar 	end_houre = null; 
	public static Date					day = null;
	
	public static char sep = ';';

	public static ExcludeId excludeId = null;
	public static int stackDepth = 0;
	
	public static Vector format = new Vector();
	
	// --- fields position in the log file
	
	public static int		MESSAGE_ID		= 0;
	public static int		MESSAGE_TEXT	= 0;
	public static int		SEVERITY		= 0;
	public static String 	MESSAGE_START 	= null;

	public static Vector files = new Vector(); // logs to work on
 
	public static Hashtable errorMessage = new Hashtable(); // BEA support database
	

	protected  Parameter() {
		
		// TODO Auto-generated constructor stub
	}
	
	   public static Parameter getInstance()  { // double check pattern
		   
		     if (instance == null) {
		    	 
		    	 synchronized(Parameter.class) {
		    		 
		    		 Parameter inst = instance; 
		    		 
		    		 if (inst == null) {
		    			 
		    			 synchronized(Parameter.class) { inst = new Parameter(); }
		    			 instance = inst;
		    		 }
		    	 }
		     }
		     
		     return instance;
	   }
	
	
	 /*
	  * read arguments and load static ressources
	  */

	public static void input( String[] args ) {

//		Vector fileNames = new Vector();

		String param, value = null;
		StringTokenizer arg = null;
		Hashtable lesParametres = new Hashtable();

		// split args into a dictionary
		
		for (int i = 0; i < args.length; i++) { // read arguments

			arg = new StringTokenizer(args[i], "=");

			if (arg.countTokens() != 2) { // in cas of error

				System.err.println( Parameter.PARAM );
				System.exit(1);
			}
			
			param = arg.nextToken();
			value = arg.nextToken();
		
			if( value == null || value.length() == 0 ) { // in cas of empty paramter

				System.err.println( param + " : need parameters : " + Parameter.PARAM );
				System.exit(1);
			}			
		
			lesParametres.put( param, value );
		}
		
		
		
		
		
		/*
		 * input parameters
		 */

		
		
		
		if( lesParametres.containsKey( "input" ) ) {	// input={file/liste/directory}
			
			param = (String) lesParametres.get( "input" );
			
			StringTokenizer split = new StringTokenizer( param, ",");
			String name = null;
			File f = null;
			
			while( split.hasMoreTokens() ) {
				
				name = (String) split.nextToken();

				if( name == null || name.length() == 0 ) { // in case of en empty parameter

					System.err.println( param + " : empty element in liste (" + value + ")" );
					System.exit(1);
				}					
				
				f = new File(name);
//				Vector files = new Vector();

				if( f.isDirectory() ) { // in case of a directory
					
					Parameter.files = Function.traverse( f, Parameter.files );
					
				} else {

					Parameter.files.add(name);						
				}
			}
			
		} else { // default
			
			System.err.println( "need the parameter : file={file/liste/directory}" );
			System.exit(1);
		}	
		

		
		
		
		
		if( lesParametres.containsKey( "output" ) ) {	// output={directory}{Default=}
			
			param = (String) lesParametres.get( "output" );
			
			if( param == null || param.length() == 0 ) {
				
				param = "document_root";
			}
			
			Parameter.rootOutput = param;
		
		} else Parameter.rootOutput = "document_root";
		
		Function.mkdir(Parameter.rootOutput);
		
		
		
		
		
		
		if( lesParametres.containsKey( "occurance_log" ) ) {	// [occurance_log=[true/false}{Default=false}]
			
			param = (String) lesParametres.get( "occurance_log" );
			
			if( param != null && param.length() > 0 ) {

				if( ! param.equals("true") && ! param.equals("false") ) {

					System.err.println( "[occurance_log=[true/false}{Default=true}]" );
					System.exit(1);				

				} else { 
					
					if( param.equals("true") ) 	{ 

						Parameter.occuranceLog = true;
					
					} else Parameter.occuranceLog = false;
				}				

			} else Parameter.occuranceLog = true;

		} else Parameter.occuranceLog = true;
		
		
		
		
		
		
		if( lesParametres.containsKey( "percent_approximate" ) ) {	// [percent_approximate={[0-100]}{Default=50}]
			
			param = (String) lesParametres.get( "percent_approximate" );
			float paramf = Float.parseFloat(param);
			
			if( paramf < 0 && paramf > 100 ) {
				
				System.err.println( "[percent_approximate={[0-100]}{Default=50}]" );
				System.exit(1);				
			
			} else {
				
				Parameter.percentApproximate = paramf;
			}
			
		} else  Parameter.percentApproximate = 50;	
		
		
		
		
		
		
		if( lesParametres.containsKey( "debug" ) ) {	// [debug={true/false}{default=false}]
			
			param = (String) lesParametres.get( "debug" );
			
			if( ! param.equals("true") && ! param.equals("false") ) {

				System.err.println( "[debug={true/false}{default=false}]" );
				System.exit(1);				

			} else { 
				
				if( param.equals("true") ) 	{ Parameter.debug = true; }
				else 						{ Parameter.debug = false; }
			}
			
		} else Parameter.debug = false;
		
		
		
		
		
		
		if( lesParametres.containsKey( "exact_match" ) ) {	// [exact_match={true/false}{Default=false}]
			
			param = (String) lesParametres.get( "exact_match" );
			
			if( ! param.equals("true") && ! param.equals("false") ) {

				System.err.println( "[exact_match={true/false}{Default=false}]" );
				System.exit(1);				

			} else { 
				
				if( param.equals("true") ) 	{ Parameter.exactMatch = true; }
				else 						{ Parameter.exactMatch = false; }
			}
			
		} else Parameter.exactMatch = false;
		
		
		
		

		if( lesParametres.containsKey( "version" ) ) { // [version={version de Weblogic}]
			
			version = (String) lesParametres.get( "version" );

		} else {
			
			System.err.println( "version={Weblogic version : 6/7/8/9/10/etc ...}" );
			System.exit(1);					
		}

		
		
		
		if( lesParametres.containsKey( "after" ) ) { // [after={"yyyy/MM/dd hh'h'mm"}]
			
			param = (String) lesParametres.get( "after" );
			
			if( param != null && param.length() != 0 ) {
				
				try {
					
					Parameter.afterDate = new SimpleDateFormat(Parameter.dateFilter).parse(param);
				
				} catch (ParseException e) {
						
					System.err.println("wrong param ["+param+"] should be [after={\"yyyy/MM/dd hh'h'mm\"}]");
					e.printStackTrace();
				} 
			}
		}

		if( lesParametres.containsKey( "before" ) ) { // [to={"yyyy/MM/dd hh'h'mm"}]
			
			param = (String) lesParametres.get( "before" );
			
			if( param != null && param.length() != 0 ) {
				
				try {
					
					Parameter.beforeDate = new SimpleDateFormat(Parameter.dateFilter).parse(param);
				
				} catch (ParseException e) {
						
					System.err.println("wrong param ["+param+"] should be [before={\"yyyy/MM/dd hh'h'mm\"}]");
					e.printStackTrace();
				} 
			}
		}

		
		
		
	
		
		if( lesParametres.containsKey( "day" ) ) { // [day={"yyyy/MM/dd"}]
			
			param = (String) lesParametres.get( "day" );
			
			if( param != null && param.length() != 0 ) {
				
				try {
					
					Parameter.afterDate = new SimpleDateFormat(Parameter.dateFilter).parse(param+" 00h00");
					Parameter.beforeDate = new SimpleDateFormat(Parameter.dateFilter).parse(param+" 23h59");
				
				} catch (ParseException e) {
						
					System.err.println("wrong param ["+param+"] should be [day={\"yyyy/MM/dd\"}]");
					e.printStackTrace();
				} 
			}
		}
		
		
		if( lesParametres.containsKey( "day" ) ) { // [day={"yyyy/MM/dd"}]
			
			param = (String) lesParametres.get( "day" );
			
			if( param != null && param.length() != 0 ) {
				
				try {
					
					Parameter.afterDate = new SimpleDateFormat(Parameter.dateFilter).parse(param+" 00h00");
					Parameter.beforeDate = new SimpleDateFormat(Parameter.dateFilter).parse(param+" 23h59");
				
				} catch (ParseException e) {
						
					System.err.println("wrong param ["+param+"] should be [day={\"yyyy/MM/dd\"}]");
					e.printStackTrace();
				} 
			}
		}		
		
		
		
		
		
		
		if( lesParametres.containsKey( "ExcludeIdFile" ) ) { // [ExcludeIdFile=\"{file}.id\"]
			
			param = (String) lesParametres.get( "ExcludeIdFile" );
			
			if( param != null && param.length() != 0 ) {
				
				Parameter.excludeId = new ExcludeId(param);
			}
		}			
	
		
		if( lesParametres.containsKey( "StackDepth" ) ) { // [StackDepth=\"{nb of stack line to compare}\"]
			
			param = (String) lesParametres.get( "StackDepth" );
			
			if( param != null && param.length() != 0 ) {
				
				Parameter.stackDepth = Integer.parseInt(param);
			}
		}	
		
		
		
		
		if( lesParametres.containsKey( "exclude_ranger_houre" ) ) { // [exclude_ranger_houre={[hh:mm-hh:mm]}]
				
				param = (String) lesParametres.get( "exclude_ranger_houre" );
				
				if( param != null && param.length() != 0 ) {
					
					int houre_brefore = Integer.parseInt( param.substring( 1, 3) );
					int minut_brefore = Integer.parseInt( param.substring( 4, 6) );
					int houre_after = Integer.parseInt( param.substring( 7, 9) );
					int minut_after = Integer.parseInt( param.substring( 10, 12) );

					day = new Date();

					Parameter.start_houre = Parameter.getGregorianCalendar( houre_brefore, minut_brefore );
					Parameter.end_houre = Parameter.getGregorianCalendar( houre_after, minut_after );
				}
			}
		
		/*
		 * internal ressources
		 */

if( Parameter.debug ) { System.out.println( "try to get support.csv file" ); }			
		
	Parameter.loadErrorMessage("WLSLogReport.internal/" + Parameter.version + "/support.csv");

		
		
		
if( Parameter.debug ) { System.out.println( "try to get format.properties file" ); }			
		
		param = "WLSLogReport.internal/" + Parameter.version + "/format.properties";		
			
		String str = null;
		
		try { // try in a java environement
        	
if( Parameter.debug ) { System.out.println( "try to get format.properties file in folder env" ); }

			BufferedReader in = null;
			in = new BufferedReader(new FileReader(param));

			while ((str = in.readLine()) != null) {
				
				Parameter.format.add(str);			
			}				
			
		} catch ( IOException e ) {
			
if( Parameter.debug ) { System.out.println( "try to get format.properties file in CLASSPATH env" ); }

			InputStream is = Parameter.class.getClassLoader().getResourceAsStream(param);
			BufferedInputStream bis = new BufferedInputStream(is);
			DataInputStream dis = new DataInputStream(bis);
			
			try {

				while( dis.available() != 0 ) { 
					
					str = dis.readLine();

					Parameter.format.add(str); 				
				}					
				
			} catch (IOException e1) {

				System.err.println("can't find the format.properties file !!!");
			}
		}				
			


		
if( Parameter.debug ) { System.out.println( "try to get key.properties file" ); }			

		param = "WLSLogReport.internal/" + Parameter.version + "/key.properties";		
			
			Properties properties = new Properties();
			
			InputStream file = null;
			
			try {
				
				try { // try in a java environement
		        	
if( Parameter.debug ) { System.out.println( "try to get key.properties file in folder env" ); }

					file = new FileInputStream(param);

				} catch ( IOException e ) {

if( Parameter.debug ) { System.out.println( "try to get key.properties file in CLASSPATH env" ); }

					file = Parameter.class.getClassLoader().getResourceAsStream( param );
				}
				
				if ( file == null ) {

					try { throw new Exception("The file [" + param + "] can't be accessed !");

					} catch (Exception e) { e.printStackTrace(); } 	
					
					return;
				}
				
				
				
				
				

				properties.load(file);
				
				Parameter.MESSAGE_ID = Integer.parseInt( properties.get("MESSAGE_ID").toString() );
				Parameter.MESSAGE_TEXT = Integer.parseInt( properties.get("MESSAGE_TEXT").toString() );
				Parameter.SEVERITY = Integer.parseInt( properties.get("SEVERITY").toString() );
				Parameter.MESSAGE_START = (String) properties.get("MESSAGE_START");			

				Parameter.dateFormat =  new SimpleDateFormat( (String) properties.get("MESSAGE_DATE_FORMAT") );
				Parameter.language = (String) properties.get("MESSAGE_DATE_LANGUAGE");
				Parameter.country = (String) properties.get("MESSAGE_DATE_COUNTRY");

			} catch (IOException e) { 
				
				System.err.println("can't find the key.properties file !!!"); 
			}

			try {
			
			Parameter.errorLog  = new BufferedWriter( new FileWriter( Parameter.rootOutput + System.getProperty("file.separator") + "error.log" ) );
			Parameter.unknownIDLog  = new BufferedWriter( new FileWriter( Parameter.rootOutput + System.getProperty("file.separator") + "wrongID.log" ) );
			Parameter.excludeIDLog  = new BufferedWriter( new FileWriter( Parameter.rootOutput + System.getProperty("file.separator") + "excludeID.log" ) );
		
		} catch (IOException e) {

			System.err.println("Can't create the error.log");
		}
		
		
		// forcer le format de date en paramtre de la commande plutt que dans le fichiers de conf interne.
		
		if( lesParametres.containsKey( "DateLanguage" ) ) { // [DateLanguage={"fr"}]
			
			param = (String) lesParametres.get( "DateLanguage" );
			Parameter.language = param;
		}		

		if( lesParametres.containsKey( "DateCountry" ) ) { // [DateCountry={"Fr"}]
			
			param = (String) lesParametres.get( "DateCountry" );
			Parameter.country = param;
		}		
		
		if( lesParametres.containsKey( "DateFormat" ) ) { // [MESSAGE_DATE_FORMAT={"MMM dd, yyyy hh:mm:ss z "}]
			
			param = (String) lesParametres.get( "DateFormat" );

			Parameter.locale = new Locale(Parameter.language,Parameter.country);
			Parameter.dateFilter = param;
			Parameter.dateFormat = new SimpleDateFormat(param,Parameter.locale);
		}		
		
		
if( Parameter.debug ) { System.out.println( Parameter.toStringIt() ); }			
			

	}	
	
	
	public static GregorianCalendar getGregorianCalendar( int houre, int minute ) {
		
		GregorianCalendar gregorianCalendar = new GregorianCalendar();
		
		gregorianCalendar.setTime(Parameter.day);
		
		gregorianCalendar.set(Calendar.HOUR_OF_DAY, houre);
		gregorianCalendar.set(Calendar.MINUTE, minute);
		gregorianCalendar.set(Calendar.SECOND, 0);
		gregorianCalendar.set(Calendar.MILLISECOND, 0);

		return gregorianCalendar;
	}
	
	public static boolean inRangeHoureToExclude( Date date ) {
		
		boolean isIn = false;

		int houre = date.getHours();
		int minute = date.getMinutes();
		
		GregorianCalendar gregorianCalendar = Parameter.getGregorianCalendar( houre, minute );
		
		if( gregorianCalendar.after(Parameter.start_houre) &&gregorianCalendar.before(Parameter.end_houre) ) { isIn = true; }
		
		return isIn;
	}
	
	public static void close() {
		
		try {
			
			Parameter.errorLog.close();
			Parameter.unknownIDLog.close();
			Parameter.excludeIDLog.close();

		} catch (IOException e) {

			e.printStackTrace();
		}
	}
	
	public static String toStringIt() {
		
		StringBuffer result = new StringBuffer();
		
		result.append( "debug:" + Parameter.debug + "\n" );

		result.append( "occuranceLog = " + Parameter.occuranceLog + "\n");
		result.append( "percentApproximate = " + Parameter.percentApproximate + "\n");
		result.append( "exactMatch = " + Parameter.exactMatch + "\n");
		result.append( "error_message = " + Parameter.error_message + "\n");
		result.append( "sep = " + Parameter.sep + "\n");
		result.append( "format = " + Parameter.format + "\n");
		
		if( afterDate != null ) {result.append( "after = " + afterDate + "\n");}
		if( beforeDate != null ) {result.append( "before = " + beforeDate + "\n");}
		
		result.append( "MESSAGE_ID = " + Parameter.MESSAGE_ID + "\n");
		result.append( "MESSAGE_TEXT = " + Parameter.MESSAGE_TEXT + "\n");
		result.append( "SEVERITY = " + Parameter.SEVERITY + "\n");
		result.append( "MESSAGE_START = " + Parameter.MESSAGE_START + "\n");

		result.append( "EXCLUDE ID = " + Parameter.excludeId + "\n");
		
		result.append( "input:" + "\n" );		
		for (int i = 0; i < Parameter.files.size(); i++) {

			result.append( "----->" + Parameter.files.elementAt(i) + "\n" );			
		}

		result.append( "sort_log:" + Parameter.occuranceLog + "\n" );
		
		return result.toString();
	}
	
	/*
	 * Chargement du fichier support BEA
	 */
	
	public static boolean isErrorMessageReferenced( String ID ) {
		
		boolean foundIt = true;
		String value = null;
		ErrorMessage found = null;
		
		if( ! ID.startsWith("BEA-")) { return false; }

		StringTokenizer st = new StringTokenizer( ID, "-" );
		value = st.nextToken();
		value = st.nextToken();

		found = (ErrorMessage) Parameter.errorMessage.get(value);

		if( found != null ) foundIt = true;
		else foundIt = false;
		
		return foundIt;
	}
	
	public static void loadErrorMessage( String fileName ) {

		String str = null;
		StringTokenizer st = null;
		
		ErrorMessage errorMessage = null;
		
		try { // essayer dans un environnement Java

if( Parameter.debug ) { System.out.println( "get support.csv in a FILE environnement" ); }			
        	
			BufferedReader in = null;
			in = new BufferedReader(new FileReader(fileName));
			while ((str = in.readLine()) != null) {
				
				st = new StringTokenizer( str, "|" );
				
				if( st.countTokens() > 0 ) {
				
					errorMessage = new ErrorMessage();
					
					if( st.hasMoreTokens() ) { 	errorMessage.id = st.nextToken(); }
					if( st.hasMoreTokens() ) { errorMessage.validity = st.nextToken(); }
					if( st.hasMoreTokens() ) { errorMessage.severity = st.nextToken(); }
					if( st.hasMoreTokens() ) { errorMessage.severityInfo = st.nextToken(); }
					if( st.hasMoreTokens() ) { errorMessage.description = st.nextToken(); }
					if( st.hasMoreTokens() ) { errorMessage.cause = st.nextToken(); }
					if( st.hasMoreTokens() ) { errorMessage.action = st.nextToken(); }
				}
				
				Parameter.errorMessage.put( errorMessage.id, errorMessage );
			}				
			
			in.close();
			
		} catch ( IOException e ) {

if( Parameter.debug ) { System.out.println( "get support.csv in a CLASSPATH environnement" ); }			

			InputStream is = Parameter.class.getClassLoader().getResourceAsStream(fileName);
			BufferedInputStream bis = new BufferedInputStream(is);
			DataInputStream dis = new DataInputStream(bis);
			
			try {

				while( dis.available() != 0 ) { 
					
					str = dis.readLine();
					
					st = new StringTokenizer( str, "|" );
//System.out.print(".");					
					if( st.countTokens() > 0 ) {
					
						errorMessage = new ErrorMessage();
						
						if( st.hasMoreTokens() ) { 	errorMessage.id = st.nextToken(); }
						if( st.hasMoreTokens() ) { errorMessage.validity = st.nextToken(); }
						if( st.hasMoreTokens() ) { errorMessage.severity = st.nextToken(); }
						if( st.hasMoreTokens() ) { errorMessage.severityInfo = st.nextToken(); }
						if( st.hasMoreTokens() ) { errorMessage.description = st.nextToken(); }
						if( st.hasMoreTokens() ) { errorMessage.cause = st.nextToken(); }
						if( st.hasMoreTokens() ) { errorMessage.action = st.nextToken(); }
					}
					
					Parameter.errorMessage.put( errorMessage.id, errorMessage );
				}					
			
				dis.close();
				
			} catch (IOException e1) {
				System.err.println("Failed to load support.csv (can't find)");
			}
		}		
	}		
	
	public static void debug( String info ) {
		
		if( Parameter.debug ) {
			
			System.out.println( "[" + info + "]" );
		}
	}	
}
