package wls.tools.logreport;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Enumeration;
import java.util.Hashtable;
import java.util.StringTokenizer;
import java.util.Vector;
import java.util.regex.Pattern;

public class Report {

	private int nbErrorLog = 0;
	private int nbunknownIDLog = 0;
	private int nbExcludeIDLog = 0;
	
	private Date dateStart = null;
	private Date dateEnd = null;
	
	
	public void putDateRange( Date currentDate ) {
		
		if( this.dateStart == null ) { this.dateStart = currentDate; }
		else if( currentDate.before(this.dateStart) )  
			{ this.dateStart = currentDate; } 
	
		if( this.dateEnd == null ) { this.dateEnd = currentDate; }
		else if( currentDate.after(this.dateEnd) )  
			{ this.dateEnd = currentDate; } 
	}
	
	public void toErrorLog( String fileName, String line ) {
	
		this.toExceptionLog( fileName, line, Parameter.errorLog );
		this.nbErrorLog++;
	}
	
	public void toUnknownIDLog( String fileName, String line ) {
		
		this.toExceptionLog( fileName, line, Parameter.unknownIDLog );
		this.nbunknownIDLog++;
	}
	
	public void toExcludeIDLog( String fileName, String line ) {
		
		this.toExceptionLog( fileName, line, Parameter.excludeIDLog );
		this.nbExcludeIDLog++;
	}	
	
	private void toExceptionLog( String fileName, String line, BufferedWriter writerLog ) {
		
		try {
			
			writerLog.write("------------------------------------------------------------------------------------" + "\n" );
			writerLog.write("fichier           : " + fileName + "\n" );
			writerLog.write("message           : " + line + "\n" );
		
		} catch (IOException e) { e.printStackTrace(); } 		
	}
	
	private Hashtable severitys = new Hashtable();
	
	public void pushRecord( Record record ) {
		
		SeverityRessource currentSeverityRessource = null;
		String currentSeverityName = (String) record.champs.get(Parameter.SEVERITY);
		
		currentSeverityRessource = (SeverityRessource) this.severitys.get(currentSeverityName);

		if( currentSeverityRessource == null ) { // cration de la severit si pas existante
			
			currentSeverityRessource = new SeverityRessource(currentSeverityName);
			this.severitys.put( currentSeverityName, currentSeverityRessource );
		}
		
		currentSeverityRessource.pushRecord(record);
	}		
	
	public void closeReport() { // fermeture du rapport (gnration des ressources)
		
		
		int taille_cellule_centrage = 20;
		int taille_cellule_gauche = taille_cellule_centrage;
		int taille_cellule_droite=100 - taille_cellule_centrage;
		String color_header = "red";
			
		String header_style_bgcolor = "204, 204, 255"; 		
		String header_gauche_style = "font-style: italic; background-color: rgb(" + header_style_bgcolor + "); font-weight: bold; text-align: center;";
		String header_droite_style = "font-style: italic; background-color: rgb(" + header_style_bgcolor + "); font-weight: bold; text-align: center;";

		String ligne1_style_bgcolor = "255, 255, 204"; 		
		String ligne1_gauche_style = "font-weight: bold; background-color: rgb(" + ligne1_style_bgcolor + ");";
		String ligne1_droite_style = "font-style: bold; background-color: rgb(" + ligne1_style_bgcolor + ");";

		String ligne2_style_bgcolor = ""; 		
		String ligne2_gauche_style = "font-style: bold; font-weight: bold;";
		String ligne2_droite_style = "font-style: bold;";
		
		// gestion de la couleure de ligne (alterne)
		int ligneX_style = 0;
		String ligne_gauche_style = null;
		String ligne_droite_style = null;		
		
		
		String currentSeverityName = null;
		SeverityRessource currentSeverityRessource = null;
		
		try {
			
			BufferedWriter index = new BufferedWriter( new FileWriter( Parameter.rootOutput + System.getProperty("file.separator") + "index.html" ) );
		
			index.write("<table border=\"1\" cellpadding=\"4\" width=\"100%\">");
			index.write("<tbody>");
			index.write("<tr align=\"center\"><td style=\"background-color: rgb(255, 0, 0);\" colspan=\"2\" rowspan=\"1\"><big><big><big><big><big>" + "WLS LOG REPORT" + "</big></big></big></big></big></td></tr><tr>");
			
			SimpleDateFormat sdf = new SimpleDateFormat( Parameter.dateFilter );
			Date date = new Date();
			String laDate = sdf.format(date);
			
			index.write( "<tr align=\"center\"><td style=\"background-color: rgb(255, 0, 0);\" colspan=\"2\" rowspan=\"1\">" );
			index.write( "<small><small><big>GENERATED ON [" + laDate + "] </big></small></small>");
if( this.dateStart != null && this.dateEnd != null ) {
			index.write( "<small><small><big>FROM [" + sdf.format(this.dateStart) + "] TO [" + sdf.format(this.dateEnd) + "] </big></small></small>" );
}
index.write( "<small><small><big>FROM WLS V." + Parameter.version + " </big></small></small>" );
			index.write( "</td></tr><tr>");

			index.write( "<tr align=\"center\"><td style=\"background-color: rgb(255, 0, 0);\" colspan=\"2\" rowspan=\"1\">" );
			if( this.nbErrorLog > 0 ) index.write( "<small><small><a href=\"error.log\"><big> {ERRORS}</big></a></small></small>" );
			if( this.nbunknownIDLog > 0 ) index.write( "<small><small><a href=\"wrongID.log\"><big> {WRONG ID}</big></a></small></small>" );
			if( this.nbExcludeIDLog > 0 ) index.write( "<small><small><a href=\"excludeID.log\"><big> {EXCLUDE ID}</big></a></small></small>" );
			index.write( "</td></tr><tr>");

			index.write("<tr>");
			
			index.write("<table border=\"0\" cellpadding=\"1\" width=\"100%\">");
			index.write("  <tbody>");

			// HEADER
			index.write("    <tr>");
			index.write("      <td style=\"" + header_gauche_style + "\" width=\"" + taille_cellule_gauche + "%\" align=\"right\" valign=\"top\">");
			index.write("      <p class=\"table\"><b>" + "TOTAL TYPE" + "</b></a>");
			index.write("      </p>");
			index.write("      </td>");		
			index.write("      <td style=\"" + header_gauche_style + "\" width=\"" + taille_cellule_gauche + "%\" align=\"right\" valign=\"top\">");
			index.write("      <p class=\"table\"><b>" + "TOTAL MESSAGE" + "</b></a>");
			index.write("      </p>");
			index.write("      </td>");			
			index.write("      <td style=\"" + header_droite_style + "\" width=\"" + taille_cellule_droite + "%\" valign=\"top\">" + "SEVERITY NAME" + "</td>");
			index.write("    </tr>");
			
			for( Enumeration e = this.severitys.keys(); e.hasMoreElements(); ) {
				
				currentSeverityName = (String) e.nextElement();
					
				if( currentSeverityName != null && currentSeverityName.length() > 0 ) {

					currentSeverityRessource = (SeverityRessource) this.severitys.get( currentSeverityName );
					
					if( currentSeverityRessource != null ) {
						
						// gestion de la couleure de ligne (alterne)
						if( ligneX_style++%2 == 0 ) { ligne_gauche_style = ligne2_gauche_style; ligne_droite_style = ligne2_droite_style;}	else { ligne_gauche_style = ligne1_gauche_style; ligne_droite_style = ligne1_droite_style;}				
						
						index.write("    <tr>");
						index.write("      <td style=\"" + ligne_gauche_style + "\" width=\"" + taille_cellule_gauche + "%\" align=\"center\" valign=\"top\">");
						index.write("      <p class=\"table\">" +
								"<big><big><big><big><b>" + currentSeverityRessource.records.size() + "</b></big></big></big></big>"
								);
						index.write("      </p>");
						index.write("      </td>");
						
						index.write("      <td style=\"" + ligne_gauche_style + "\" width=\"" + taille_cellule_gauche + "%\" align=\"center\" valign=\"top\">");
						index.write("      <p class=\"table\">" +
											"<big><big><big><big><b>" + currentSeverityRessource.total + "</b></big></big></big></big>"
								);
						index.write("      </p>");
						index.write("      </td>");
						
						
						index.write("      <td style=\"" + ligne_droite_style + "\" width=\"" + taille_cellule_droite + "%\" align=\"left\" valign=\"top\">");
						index.write("      <p class=\"table\">" +
//											"<big><big><big><big><b><a href=" + currentSeverityRessource.severityName + System.getProperty("file.separator") + currentSeverityRessource.severityName + ".html>" + currentSeverityRessource.severityName + "</a><b></big></big></big></big>" 
											"<big><big><big><big><b><a href=" + currentSeverityRessource.severityName + "/" + currentSeverityRessource.severityName + ".html>" + currentSeverityRessource.severityName + "</a><b></big></big></big></big>"
								);
						index.write("      </p>");
						index.write("      </td>");
						
/*						
						index.write("      <td style=\"" + ligne_droite_style + "\" width=\"" + taille_cellule_droite + "%\" valign=\"top\">" + 
								"<b>" + currentSeverityRessource.total + "</b>"
											+ "</td>");
*/

						
						index.write("    </tr>");				
	
						currentSeverityRessource.closeSeverityRessources();
					}					
				}
				
			}

			index.write("  </tbody>");
			index.write("</table>");
			
			index.write("<br>");	
			
			index.write("</tr>");
			index.write("</tbody>");
			index.write("</table>");
			
			index.close();
			
		} catch (IOException e1) {
			// TODO Auto-generated catch block
			e1.printStackTrace();
		}
	}
}
