package wls.tools.logreport;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.Hashtable;
import java.util.StringTokenizer;
import java.util.Vector;

/*
 * Classe supportant toutes les ressources  ouvrir et les records types 
 */

public class SeverityRessource {

	public String severityName 			= null; // le nom de la severite
	public String severityPath 			= null; // le rpertoire de gnration
	public String severityPathOccurance = null; // le rpertoire des fichiers occurances
	
	public int total = 0; // total des record sur la severite

	public BufferedWriter outputCsvFile = null; // le fichier CSV	
	public BufferedWriter outputHtmlFile = null; // le pedant HTML
		
	public Vector records = new Vector();		// les records
	public int key = 0;							// clef d'increment des records	
	
	
	public SeverityRessource( String newSeverityName ) {
		
		super();
		
		// cration des ressources
		
		this.severityName = newSeverityName;
		this.severityPath = Parameter.rootOutput + System.getProperty("file.separator") + this.severityName;
		this.severityPathOccurance = this.severityPath + System.getProperty("file.separator") + "OCC";
		
		Function.mkdir(this.severityPath);
		Function.mkdir(this.severityPathOccurance);
		
		this.records = new Vector();
		
		try { // ouverture du fichier
			
			this.outputCsvFile = new BufferedWriter( new FileWriter( this.severityPath  + System.getProperty("file.separator") + severityName + ".csv" ));
			this.outputHtmlFile = new BufferedWriter( new FileWriter( this.severityPath  + System.getProperty("file.separator") + severityName + ".html" ));

		} catch (IOException e) {
					
			e.printStackTrace();
			System.err.println( "open file problem !");
		}				

	}
	
	/*
	 * Fermeture des ressources
	 */
	
	public void closeSeverityRessources() { // fermeture des ressource severites
		
		Record currentRecord = null;
		
		for( int i = 0; i < this.records.size(); i++ ) {
		
			currentRecord = (Record) this.records.get(i);
			
			if( currentRecord != null ) {
				
				currentRecord.closeRecordRessources();
			}
		}
		
		this.toReport();
		
		try {
			
			this.outputCsvFile.close();
			this.outputHtmlFile.close();
			
		} catch (IOException e) {
			
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}
	
	/*
	 * Insertion des records de mme severite
	 */
	
	public void pushRecord( Record record ) {
	
		Record currentRecord = null;
		
		if( this.records.size() == 0 ) { // 1er record insere
			
			record.inc(); 
			record.newAdded( this.key++, this.severityPathOccurance ); // increment de la clef
			record.recordToOccuranceLog(record);	
			record = this.findErrorMessage( record );
			
			this.records.add( record );
			this.total++;

		} else {
		
			boolean isIn = false;
			int i = 0;
			
			while( !isIn && i < this.records.size() ) { // recherche si dj dans la severite
			
				currentRecord = (Record) this.records.elementAt( i++ );
				
				if( currentRecord.equalsApproximate( record, Parameter.percentApproximate,  Parameter.stackDepth ) ) { 
		
					isIn = true; // trouve dans le report
					currentRecord.inc(); // on l'incremente
					currentRecord.recordToOccuranceLog(record);
				}			
			}
	
			if( ! isIn ) { // si pas dans le report, on l'ajoute 

				record.inc();
				record.newAdded( this.key++, this.severityPathOccurance ); // increment de la clef
				record.recordToOccuranceLog(record);			
				record = this.findErrorMessage( record );

				this.records.add( record );
			}

			this.total++;
		}
	}		
	
	/*
	 *  Affichage de la severite
	 */
	
	public String toString() {
		
		StringBuffer result = new StringBuffer();

		if( ! ( this.records.size() == 0 ) ) { 
			
			int i = 0;
			
			for ( i = 0; i < this.records.size() - 1; i++) {
				
				result.append( this.records.elementAt(i) ); result.append( "\n" );			
			}

			result.append( this.records.elementAt(i) ); result.append( "\n" );						
		}
		
		return result.toString();
	}	
	
	/*
	 * Recherche de l'information support BEA associ 
	 */
	
	private Record findErrorMessage( Record record ) {

		String idMessageErreur = null;
		ErrorMessage messageErreur = null;

		idMessageErreur = (String) record.champs.get(Parameter.MESSAGE_ID);
		if( idMessageErreur.length() >= 6 ) idMessageErreur = idMessageErreur.substring( 4, idMessageErreur.length() );

		record.errorMessage = (ErrorMessage) Parameter.errorMessage.get( idMessageErreur );

		return record;
	}
	
	/*
	 * Affichage CVS
	 */	
	
	public String toCSVHeader() {

		StringBuffer result = new StringBuffer();

		result.append( "KEY" ); result.append( Parameter.sep );
		result.append( "STATUS" ); result.append( Parameter.sep );
		result.append( "FILE NAME" ); result.append( Parameter.sep );
		result.append( "OCCURANCES" ); result.append( Parameter.sep );

		result.append( "TIMESTAMP" ); result.append( Parameter.sep );
		result.append( "SEVERITY" ); result.append( Parameter.sep );
		result.append( "SUBSYSTEM" ); result.append( Parameter.sep );
		result.append( "SERVER NAME/MACHINE NAME/THREAD ID" ); result.append( Parameter.sep );
		result.append( "USER" ); result.append( Parameter.sep );
		result.append( "TRANSACTION ID" ); result.append( Parameter.sep );
		result.append( "?" ); result.append( Parameter.sep );
		result.append( "?" ); result.append( Parameter.sep );
		result.append( "MESSAGE ID" ); result.append( Parameter.sep );
		result.append( "MESSAGE TEXT" ); result.append( Parameter.sep );

		result.append( "VALIDITY" ); result.append( Parameter.sep );
		result.append( "SEVERITY INFO" ); result.append( Parameter.sep );
		result.append( "DESCRIPTION" ); result.append( Parameter.sep );
		result.append( "CAUSE" ); result.append( Parameter.sep );
		result.append( "ACTION" ); result.append( Parameter.sep );

		return result.toString();
	}	
	
	/*
	 * Affichage du rapport pour la severite 
	 */
	
	public void toReport() {

		Record record = null;
		String errorMessage = null;
		
		if( this.records.size() != 0 ) { 

			try {
			
				int i = 0;
				
				this.outputHtmlFile.write("<table border=\"1\" cellpadding=\"4\" width=\"100%\">");
				this.outputHtmlFile.write("<tbody>");
				this.outputHtmlFile.write("<tr align=\"center\"><td style=\"background-color: rgb(255, 0, 0);\" colspan=\"2\" rowspan=\"1\"><big><big><big><big><big>" + ( (Record) this.records.get(0) ).champs.elementAt( Parameter.SEVERITY ) + "</big></big></big></big></big></td></tr><tr>");
				    
				this.outputCsvFile.write( this.toCSVHeader() + "\n" );
				    
				for ( i = 0; i < this.records.size(); i++) {
					
					record = (Record) this.records.elementAt(i);
	
					this.outputCsvFile.write( record.toCSV() + "\n" );
	
					this.outputHtmlFile.write("<tr>");
					this.outputHtmlFile.write( record.toReportHtml() + "\n" );
					this.outputHtmlFile.write("</tr>");
					
				}
				  
				this.outputHtmlFile.write("</tbody>");
				this.outputHtmlFile.write("</table>");

			} catch (IOException e) { e.printStackTrace(); }
		}
	}		
	
	

}
