package wls.tools.logreport.importerrormessage;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.StringTokenizer;

import wls.tools.logreport.Function;

/* Analyse des fichier contenant le format suivant :
 * 
 BEA-000403 
 Error: IOException occurred on socket: socket\n ioe.

 Description 
 An IO exception was encountered while reading from the socket. 
 Cause 
 An unexpected IO exception was encountered while performing IO for the socket. 
 Action 
 Check network connectivity. If situation persists after environmental issues are resolved, contact BEA Customer Support. 
 * 
 */

public class ImportErrorMessage {
	
	String directoryName = null;
	BufferedWriter outTxt = null;
	
	

	public static void main(String[] args) {

		File f = new File(args[0]);
		
		ImportErrorMessage importErrorMessage = new ImportErrorMessage( f );
		try {
			importErrorMessage.traverse(f);
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}
	

	
	public ImportErrorMessage( File f ) {
		
		try {
			
			this.directoryName = f.getName();
			
			outTxt = new BufferedWriter( new FileWriter( f.getParent() + System.getProperty("file.separator") + this.directoryName + ".csv" ) );

			} catch (IOException e) { e.printStackTrace();	}
	}



	public void traverse(File f) throws IOException {
	
		this.read(f);
		
		if (f.isDirectory()) {
			
			String[] children = f.list();
			
			for (int i = 0; i < children.length; i++) {
				
				traverse(new File(f, children[i]));
			}
		}
		
		
		
	}	
	

	public void read( File file ) throws IOException {
		
		if( file.isDirectory() ) return;

// outTxt.write( "##########" + file.getName()+ "\n");
		
		System.out.println(file.getAbsoluteFile());

		try {

			BufferedReader in = new BufferedReader( new FileReader(file));
			String str;
			boolean isFirst = true;
			
			String id = " ";
			String validity = " ";
			String severity = " ";
			String severityInfo = " ";
			String description = " ";
			String cause = " ";
			String action = " ";
			String tmpString = " ";
			String tmpVector = " ";
			StringTokenizer st = null;
			boolean isNumerical = false;
			
			while ((str = in.readLine()) != null) {
				
				str = str.trim();
				if( str.length() >= 6 ) { isNumerical = Function.isNumerical(str.substring( 0, 6 ) ); }
				else { isNumerical = false; }
				
//System.out.println(str);
				if( str.length() != 0 ) {
					
					if( str.startsWith("BEA-") || isNumerical ) { // debut d'extraction d'un enregistrement : BEA-000405(retired)  
					
						if( isFirst ) { isFirst = false; } // c'est le 1er enregistrement
						else { // affichage de l'enregistrement d'avant
							
							outTxt.write( id + "|" + validity + "|" + severity + "|" + severityInfo + "|" + description + "|" + cause + "|" + action + "\n");
//							System.out.println( id + "|" + validity + "|" + severity + "|" + severityInfo + "|" + description + "|" + cause + "|" + action + "\n");
	
							id = " ";
							validity = " ";
							severity = " ";
							severityInfo = " ";
							description = " ";
							cause = " ";
							action = " ";
							tmpString = " ";
							tmpVector = " ";
							st = null;
						}
						
						st = new StringTokenizer(str, "(" );
						if( st.countTokens() == 1 ) { 
							
							id = str;
							if( ! isNumerical ) { id = id.substring( 4, id.length() ); }
							validity = " ";
							
						} else {
							
							id = st.nextToken();
							if( ! isNumerical ) id = id.substring( 4, id.length() );
							validity = st.nextToken();
							validity = validity.substring( 0, validity.length() - 2 );
						}					
	
						str = in.readLine();
						severity = str; 
						st = new StringTokenizer( severity, ":" );
						if( severityInfo != null ) severity = st.nextToken(); severity = severity.substring( 1, severity.length() );
						
						while( st.hasMoreTokens() ) {
						
							severityInfo = severityInfo.concat( st.nextToken() );
						}
						 
						if( severityInfo != null ) severityInfo = severityInfo.substring( 1, severityInfo.length() );				

					} else if( str.startsWith("Description") ) {
						
						str = in.readLine();
						description = str;
						if( description != null ) 
							if( description.length() > 1 ) description = description.substring( 1, description.length() - 1 );

					} else 	if( str.startsWith("Cause") ) {
						
						str = in.readLine();
						cause = str;
						if( cause != null ) 
							if( cause.length() > 1 ) cause = cause.substring( 1, cause.length() - 1 );
					
					} else if( str.startsWith("Action") ) {
						
						str = in.readLine();
						action = str; str = in.readLine();
						if( action != null ) 
							if( action.length() > 1 ) action = action.substring( 1, action.length() - 1 );
					}		
				}
			}
			
			outTxt.write( id + "|" + validity + "|" + severity + "|" + severityInfo + "|" + description + "|" + cause + "|" + action + "\n" );
//			System.out.println( id + "|" + validity + "|" + severity + "|" + severityInfo + "|" + description + "|" + cause + "|" + action + "\n" );

			in.close();

		} catch (IOException e) {
			
			e.printStackTrace();
		}

	}

	
}
